Crate poststation_fw_icd

Crate poststation_fw_icd 

Reserved or “special” types and interfaces within Poststation

NOTE

For now, there is no way to “import” these definitions directly, so they are provided as examples, and the types are expected to be used directly.

See postcard-rpc#71 for more information.

Modules

bridging
Bridging
unique_id
Unique ID